import requests
from typing import List, Dict, Any

def search_dblp(query: str, max_results: int = 10) -> List[Dict[str, Any]]:
    """Search DBLP database for computer science papers.
    
    Args:
        query: The search query string
        max_results: Maximum number of results to return
        
    Returns:
        List of dictionaries with publication data including:
        - authors: List of author names
        - title: Publication title
        - venue: Publication venue
        - volume: Volume number
        - number: Publication number
        - pages: Page numbers
        - publisher: Publisher name
        - year: Publication year
        - type: Publication type
        - access: Access type
        - key: DBLP key
        - doi: DOI identifier
        - ee: Electronic edition link
        - url: DBLP page URL
    """
    try:
        # DBLP API endpoint
        url = f"https://dblp.org/search/publ/api"
        params = {
            'q': query,
            'format': 'json',
            'h': max_results
        }
        
        response = requests.get(url, params=params, timeout=10)
        response.raise_for_status()
        
        data = response.json()
        
        # Extract publications from the response
        publications = []
        if 'result' in data and 'hits' in data['result'] and 'hit' in data['result']['hits']:
            hits = data['result']['hits']['hit']
            
            # Ensure hits is a list
            if not isinstance(hits, list):
                hits = [hits]
            
            for hit in hits:
                info = hit.get('info', {})
                
                # Extract authors
                authors = []
                if 'authors' in info and 'author' in info['authors']:
                    author_data = info['authors']['author']
                    if isinstance(author_data, list):
                        authors = author_data
                    else:
                        authors = [author_data]
                
                # Create publication dictionary
                publication = {
                    'title': info.get('title', ''),
                    'authors': authors,
                    'venue': info.get('venue', ''),
                    'volume': info.get('volume', ''),
                    'number': info.get('number', ''),
                    'pages': info.get('pages', ''),
                    'publisher': info.get('publisher', ''),
                    'year': info.get('year', ''),
                    'type': info.get('type', ''),
                    'access': info.get('access', ''),
                    'key': info.get('key', ''),
                    'doi': info.get('doi', ''),
                    'ee': info.get('ee', ''),
                    'url': info.get('url', '')
                }
                
                publications.append(publication)
        
        return publications
        
    except requests.RequestException as e:
        print(f"Error fetching DBLP data: {e}")
        return []
    except Exception as e:
        print(f"Error processing DBLP data: {e}")
        return []


import arxiv

def search_arxiv(query: str, max_results: int = 10) -> list[arxiv.Result]:
    """Search for papers on arXiv."""
    search = arxiv.Search(
        query=query,
        max_results=max_results,
        sort_by=arxiv.SortCriterion.Relevance,
        sort_order=arxiv.SortOrder.Descending,
    )
    return list(search.results())



"""Basic tests for lit-mcp package."""

def test_import():
    """Test that the main module can be imported."""
    import lit_mcp.__main__ as main
    assert hasattr(main, 'mcp')
    assert hasattr(main, 'arxiv_search')
    assert hasattr(main, 'main')

def test_arxiv_search_function():
    """Test that the arxiv_search function is properly decorated."""
    import lit_mcp.__main__ as main
    # Check that the function exists and is callable
    assert callable(main.arxiv_search)
    
    # Test with a simple query (this will make an actual API call)
    try:
        results = main.arxiv_search("machine learning", max_results=1)
        assert isinstance(results, list)
        if results:  # If we got results
            assert isinstance(results[0], dict)
            assert 'title' in results[0]
            assert 'authors' in results[0]
    except Exception as e:
        # If the API call fails, that's okay for testing purposes
        print(f"API call failed (expected in some environments): {e}")

def test_dblp_search_function():
    """Test that the dblp_search function is properly decorated."""
    import lit_mcp.__main__ as main
    # Check that the function exists and is callable
    assert callable(main.dblp_search)
    
    # Test with a simple query (this will make an actual API call)
    try:
        results = main.dblp_search("machine learning", max_results=1)
        assert isinstance(results, list)
        if results:  # If we got results
            assert isinstance(results[0], dict)
            # Check for DBLP-specific attributes
            expected_attrs = ['title', 'authors', 'venue', 'volume', 'number', 
                            'pages', 'publisher', 'year', 'type', 'access', 
                            'key', 'doi', 'ee', 'url']
            for attr in expected_attrs:
                assert attr in results[0]
    except Exception as e:
        # If the API call fails, that's okay for testing purposes
        print(f"DBLP API call failed (expected in some environments): {e}")

if __name__ == "__main__":
    test_import()
    test_arxiv_search_function()
    test_dblp_search_function()
    print("All tests passed!")



#!/usr/bin/env python3
"""
Validate server.json against the MCP schema.
This script can be used locally or in CI to ensure the server.json is valid.
"""

import json
import sys
import urllib.request
from pathlib import Path

try:
    import jsonschema
except ImportError:
    print("❌ jsonschema library not found. Install with: uv add jsonschema --dev")
    sys.exit(1)


def validate_server_json():
    """Validate server.json against the MCP schema."""
    server_json_path = Path("server.json")
    
    if not server_json_path.exists():
        print("❌ server.json not found in current directory")
        return False
    
    try:
        # Load the schema
        schema_url = 'https://static.modelcontextprotocol.io/schemas/2025-09-29/server.schema.json'
        print(f"📥 Fetching schema from {schema_url}...")
        schema = json.loads(urllib.request.urlopen(schema_url).read())
        
        # Load our server.json
        print("📄 Loading server.json...")
        with open(server_json_path, 'r') as f:
            data = json.load(f)
        
        # Validate
        print("🔍 Validating against MCP schema...")
        jsonschema.validate(data, schema)
        print("✅ server.json is valid against the MCP schema!")
        return True
        
    except jsonschema.ValidationError as e:
        print(f"❌ Validation error: {e.message}")
        print(f"   Path: {'.'.join(str(p) for p in e.absolute_path)}")
        return False
    except Exception as e:
        print(f"❌ Error: {e}")
        return False


if __name__ == "__main__":
    success = validate_server_json()
    sys.exit(0 if success else 1)
